﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;

namespace testDynamicEditors
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            // This sample demonstrates how to change XamComboEditors' items dynamically, 
            // based on the value of another cell

            InitializeComponent();

            // hooking up events of the XamDataGrid
            xamDataGrid1.FieldLayoutInitialized += new EventHandler<Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs>(xamDataGrid1_FieldLayoutInitialized);
            xamDataGrid1.EditModeEnded += new EventHandler<Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs>(xamDataGrid1_EditModeEnded);
            xamDataGrid1.InitializeRecord += new EventHandler<Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs>(xamDataGrid1_InitializeRecord);
            
            // adding different temp items to the XamDataGrid
            xamDataGrid1.DataItems.Add(new TempData(MyEnumerations.Age));
            xamDataGrid1.DataItems.Add(new TempData(MyEnumerations.Sex));
            xamDataGrid1.DataItems.Add(new TempData(MyEnumerations.Location));
        }

        void xamDataGrid1_InitializeRecord(object sender, Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs e)
        {
            // This event handles the initial values of the items inside the XamDataGrid
            // so that fields are synced with each other

            // get the value of the first cell, as the value of the second depends on it
            string val = (e.Record as DataRecord).Cells[0].Value.ToString();
            
            // create a style, which will be applied at the cell of the second field
            Style s = new Style(typeof(XamComboEditor));

            // create a provider and add the correct Enum values
            ComboBoxItemsProvider provider = new ComboBoxItemsProvider();

            switch (val)
            {
                case "Sex":
                    {
                        provider.ItemsSource = Enum.GetNames(typeof(Sex));
                        break;
                    }
                case "Age":
                    {
                        provider.ItemsSource = Enum.GetNames(typeof(Age));
                        break;
                    }
                case "Location":
                    {
                        provider.ItemsSource = Enum.GetNames(typeof(Location));
                        break;
                    }
            }

            // add and apply the provider to the Style
            s.Setters.Add(new Setter(XamComboEditor.ItemsProviderProperty, provider));

            // assign the style to the cell's EditorStyle property
            (e.Record as DataRecord).Cells[1].EditorStyle = s;
        }

        void xamDataGrid1_EditModeEnded(object sender, Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs e)
        {
            // Handle this code only if the Field is "ID"
            // and set the values inside the second Field

            if (e.Cell.Field.Name == "ID")
            {
                string val = e.Cell.Value.ToString();
                CellValuePresenter cvp = CellValuePresenter.FromRecordAndField(e.Cell.Record,xamDataGrid1.FieldLayouts[0].Fields[1]) as CellValuePresenter;
                
                XamComboEditor editor = cvp.Editor as XamComboEditor;
                
                ComboBoxItemsProvider provider = new ComboBoxItemsProvider();

                switch (val)
                {
                    case "Sex":
                        {
                            provider.ItemsSource = Enum.GetNames(typeof(Sex));
                            break;
                        }
                    case "Age":
                        {
                            provider.ItemsSource = Enum.GetNames(typeof(Age));
                            break;
                        }
                    case "Location":
                        {
                            provider.ItemsSource = Enum.GetNames(typeof(Location));
                            break;
                        }
                }
                
                // setting the provider
                editor.ItemsProvider = provider;
            }
        }

        void xamDataGrid1_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
        {
            // Get the ID Primary Field
            Field f = e.FieldLayout.Fields[0];

            // Create a style that will be applied at the first field
            Style s1 = new Style(typeof(XamComboEditor));

            // Create a provider to add items of the primary Enum
            ComboBoxItemsProvider provider = new ComboBoxItemsProvider();

            // Get the values of the primary Enum
            provider.ItemsSource = Enum.GetNames(typeof(MyEnumerations));

            // add and apply the provider to the Style
            // add EventSetter to the Style to handle exiting edit mode on selection
            s1.Setters.Add(new Setter(XamComboEditor.ItemsProviderProperty, provider));
            s1.Setters.Add(new EventSetter(XamComboEditor.SelectedItemChangedEvent,new RoutedPropertyChangedEventHandler<object>(x_SelectedItemChanged)));
            
            // setting the style to the primary field
            f.Settings.EditorStyle = s1;
            
            // Initializing the second field so that 
            // it is ready with a XamComboEditor embedded
            Field f1 = e.FieldLayout.Fields[1];
            f1.Settings.EditorType = typeof(XamComboEditor);
        }

        void x_SelectedItemChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            // Force to exit edit mode of the First field on selection
            XamComboEditor x = sender as XamComboEditor;
            x.EndEditMode(true, true);
        }
    }

    // Underlying class
    public class TempData
    {
        public MyEnumerations ID { get; set; }
        public object Description { get; set; }
        public TempData(MyEnumerations enumeration)
        {
            this.ID = enumeration;
        }
    }

    // Enumerations 
    public enum MyEnumerations { Age, Sex, Location }

    public enum Age { Over_14, Over_18, Over_21}

    public enum Sex { Male, Female}

    public enum Location { Local, Regional, International }

}
